@@ -99,11 +99,11 @@ enum OCLScopeKind {
 // the corresponding constants from 'std::memory_order' enum.
 enum OCLMemOrderKind {
 #if __cplusplus >= 202002L
-  OCLMO_relaxed = static_cast<int>(std::memory_order::relaxed),
-  OCLMO_acquire = static_cast<int>(std::memory_order::acquire),
-  OCLMO_release = static_cast<int>(std::memory_order::release),
-  OCLMO_acq_rel = static_cast<int>(std::memory_order::acq_rel),
-  OCLMO_seq_cst = static_cast<int>(std::memory_order::seq_cst)
+  OCLMO_relaxed = std::memory_order_relaxed,
+  OCLMO_acquire = std::memory_order_acquire,
+  OCLMO_release = std::memory_order_release,
+  OCLMO_acq_rel = std::memory_order_acq_rel,
+  OCLMO_seq_cst = std::memory_order_seq_cst
 #else
   OCLMO_relaxed = std::memory_order::memory_order_relaxed,
   OCLMO_acquire = std::memory_order::memory_order_acquire,
@@ -170,9 +170,7 @@ struct OCLBuiltinTransInfo {
   /// Postprocessor of operands
   std::function<void(BuiltinCallMutator &)> PostProc;
   Type *RetTy;      // Return type of the translated function
-  bool IsRetSigned; // When RetTy is int, determines if extensions
-                    // on it should be a sext or zet.
-  OCLBuiltinTransInfo() : RetTy(nullptr), IsRetSigned(false) {
+  OCLBuiltinTransInfo() : RetTy(nullptr) {
     PostProc = [](BuiltinCallMutator &) {};
   }
 };
@@ -245,6 +243,7 @@ const static char AtomicInit[] = "atomic_init";
 const static char AtomicWorkItemFence[] = "atomic_work_item_fence";
 const static char Barrier[] = "barrier";
 const static char Clamp[] = "clamp";
+const static char ClockReadPrefix[] = "clock_read_";
 const static char ConvertPrefix[] = "convert_";
 const static char Dot[] = "dot";
 const static char DotAccSat[] = "dot_acc_sat";
@@ -360,8 +359,9 @@ const OCLScopeKind OCLLegacyAtomicMemScope = OCLMS_work_group;
 namespace kOCLVer {
 const unsigned CL12 = 102000;
 const unsigned CL20 = 200000;
-const unsigned CL21 = 201000;
 const unsigned CL30 = 300000;
+const unsigned CLCXX10 = 100000;
+const unsigned CLCXX2021 = 202100000;
 } // namespace kOCLVer
 
 namespace OclExt {
