@@ -224,20 +224,6 @@ template <> inline void SPIRVMap<SPIRVCapabilityKind, SPIRVCapVec>::init() {
   ADD_VEC_INIT(CapabilityBFloat16DotProductKHR, {CapabilityBFloat16TypeKHR});
   ADD_VEC_INIT(CapabilityBFloat16CooperativeMatrixKHR,
                {CapabilityBFloat16TypeKHR, CapabilityCooperativeMatrixKHR});
-  ADD_VEC_INIT(CapabilityInt4CooperativeMatrixINTEL,
-               {CapabilityInt4TypeINTEL, CapabilityCooperativeMatrixKHR});
-  ADD_VEC_INIT(internal::CapabilityBFloat16ArithmeticINTEL,
-               {CapabilityBFloat16TypeKHR});
-  ADD_VEC_INIT(internal::CapabilityAtomicInt16CompareExchangeINTEL,
-               {CapabilityInt16});
-  ADD_VEC_INIT(internal::CapabilityInt16AtomicsINTEL,
-               {internal::CapabilityAtomicInt16CompareExchangeINTEL});
-  ADD_VEC_INIT(internal::CapabilityAtomicBFloat16LoadStoreINTEL,
-               {CapabilityBFloat16TypeKHR});
-  ADD_VEC_INIT(internal::CapabilityAtomicBFloat16AddINTEL,
-               {CapabilityBFloat16TypeKHR});
-  ADD_VEC_INIT(internal::CapabilityAtomicBFloat16MinMaxINTEL,
-               {CapabilityBFloat16TypeKHR});
 }
 
 template <> inline void SPIRVMap<SPIRVExecutionModelKind, SPIRVCapVec>::init() {
@@ -300,12 +286,16 @@ template <> inline void SPIRVMap<SPIRVExecutionModeKind, SPIRVCapVec>::init() {
                {CapabilityFloatingPointModeINTEL});
   ADD_VEC_INIT(ExecutionModeSharedLocalMemorySizeINTEL,
                {CapabilityVectorComputeINTEL});
+  ADD_VEC_INIT(internal::ExecutionModeFastCompositeKernelINTEL,
+               {internal::CapabilityFastCompositeINTEL});
   ADD_VEC_INIT(ExecutionModeRegisterMapInterfaceINTEL,
                {CapabilityFPGAKernelAttributesv2INTEL});
   ADD_VEC_INIT(ExecutionModeStreamingInterfaceINTEL,
                {CapabilityFPGAKernelAttributesINTEL});
   ADD_VEC_INIT(ExecutionModeNamedBarrierCountINTEL,
                {CapabilityVectorComputeINTEL});
+  ADD_VEC_INIT(internal::ExecutionModeNamedSubgroupSizeINTEL,
+               {internal::CapabilitySubgroupRequirementsINTEL});
   ADD_VEC_INIT(ExecutionModeMaximumRegistersINTEL,
                {CapabilityRegisterLimitsINTEL});
   ADD_VEC_INIT(ExecutionModeMaximumRegistersIdINTEL,
@@ -479,6 +469,8 @@ template <> inline void SPIRVMap<Decoration, SPIRVCapVec>::init() {
   ADD_VEC_INIT(DecorationAliasScopeINTEL,
                {CapabilityMemoryAccessAliasingINTEL});
   ADD_VEC_INIT(DecorationNoAliasINTEL, {CapabilityMemoryAccessAliasingINTEL});
+  ADD_VEC_INIT(internal::DecorationCallableFunctionINTEL,
+               {internal::CapabilityFastCompositeINTEL});
   ADD_VEC_INIT(DecorationMediaBlockIOINTEL, {CapabilityVectorComputeINTEL});
   ADD_VEC_INIT(DecorationStallEnableINTEL,
                {CapabilityFPGAClusterAttributesINTEL});
